==> stripe-1.82.0.tar.gz: stripe-1.82.0/tests/api_resources/test_subscription_item.py <==
from __future__ import absolute_import, division, print_function

import stripe
from tests.helper import StripeTestCase


TEST_RESOURCE_ID = 'si_123'


class SubscriptionItemTest(StripeTestCase):
    def test_is_listable(self):
        resources = stripe.SubscriptionItem.list()
        self.assert_requested(
            'get',
            '/v1/subscription_items'
        )
        self.assertIsInstance(resources.data, list)
        self.assertIsInstance(resources.data[0], stripe.SubscriptionItem)

    def test_is_retrievable(self):
        resource = stripe.SubscriptionItem.retrieve(TEST_RESOURCE_ID)
        self.assert_requested(
            'get',
            '/v1/subscription_items/%s' % TEST_RESOURCE_ID
        )
        self.assertIsInstance(resource, stripe.SubscriptionItem)

    def test_is_creatable(self):
        resource = stripe.SubscriptionItem.create(
            plan='plan',
            subscription='sub_123'
        )
        self.assert_requested(
            'post',
            '/v1/subscription_items'
        )
        self.assertIsInstance(resource, stripe.SubscriptionItem)

    # TODO: Fix this test
    # def test_is_saveable(self):
    #    resource = stripe.SubscriptionItem.retrieve(TEST_RESOURCE_ID)
    #    resource.plan = 'plan'
    #    resource.save()
    #    self.assert_requested(
    #        'post',
    #        '/v1/subscription_items/%s' % resource.id,
    #        {
    #            'plan': 'plan',
    #        },
    #    )

    def test_is_modifiable(self):
        resource = stripe.SubscriptionItem.modify(
            TEST_RESOURCE_ID,
            plan='plan'
        )
        self.assert_requested(
            'post',
            '/v1/subscription_items/%s' % TEST_RESOURCE_ID,
            {
                'plan': 'plan',
            },
        )
        self.assertIsInstance(resource, stripe.SubscriptionItem)

    def test_is_deletable(self):
        resource = stripe.SubscriptionItem.retrieve(TEST_RESOURCE_ID)
        # Unfortunately stripe-mock will return a resource with a different
        # ID, so we need to store the original ID for the request assertion
        resource_id = resource.id
        resource.delete()
        self.assert_requested(
            'delete',
            '/v1/subscription_items/%s' % resource_id
        )
        self.assertTrue(resource.deleted)

==> stripe-2.1.0.tar.gz: stripe-2.1.0/tests/api_resources/test_subscription_item.py <==
from __future__ import absolute_import, division, print_function

import stripe


TEST_RESOURCE_ID = 'si_123'


class TestSubscriptionItem(object):
    def test_is_listable(self, request_mock):
        resources = stripe.SubscriptionItem.list()
        request_mock.assert_requested(
            'get',
            '/v1/subscription_items'
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], stripe.SubscriptionItem)

    def test_is_retrievable(self, request_mock):
        resource = stripe.SubscriptionItem.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested(
            'get',
            '/v1/subscription_items/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.SubscriptionItem)

    def test_is_creatable(self, request_mock):
        resource = stripe.SubscriptionItem.create(
            plan='plan',
            subscription='sub_123'
        )
        request_mock.assert_requested(
            'post',
            '/v1/subscription_items'
        )
        assert isinstance(resource, stripe.SubscriptionItem)

    # TODO: Fix this test
    # def test_is_saveable(self):
    #    resource = stripe.SubscriptionItem.retrieve(TEST_RESOURCE_ID)
    #    resource.plan = 'plan'
    #    resource.save()
    #    request_mock.assert_requested(
    #        'post',
    #        '/v1/subscription_items/%s' % resource.id,
    #        {
    #            'plan': 'plan',
    #        },
    #    )

    def test_is_modifiable(self, request_mock):
        resource = stripe.SubscriptionItem.modify(
            TEST_RESOURCE_ID,
            plan='plan'
        )
        request_mock.assert_requested(
            'post',
            '/v1/subscription_items/%s' % TEST_RESOURCE_ID,
            {
                'plan': 'plan',
            },
        )
        assert isinstance(resource, stripe.SubscriptionItem)

    def test_is_deletable(self, request_mock):
        resource = stripe.SubscriptionItem.retrieve(TEST_RESOURCE_ID)
        # Unfortunately stripe-mock will return a resource with a different
        # ID, so we need to store the original ID for the request assertion
        resource_id = resource.id
        resource.delete()
        request_mock.assert_requested(
            'delete',
            '/v1/subscription_items/%s' % resource_id
        )
        assert resource.deleted is True
